Stan Math Library: stan::math::coupled_ode_system< F, T1, T2 > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::coupled_ode_system< F, T1, T2 > Struct Template Reference

Base template class for a coupled ordinary differential equation system, which adds sensitivities to the base system. More...

`#include <coupled_ode_system.hpp>`

## Detailed Description

### template<typename F, typename T1, typename T2>
struct stan::math::coupled_ode_system< F, T1, T2 >

Base template class for a coupled ordinary differential equation system, which adds sensitivities to the base system.

This template class declaration should not be instantiated directly — it is just here to serve as a base for its specializations, some of which are defined in namespace `stan::aggrad`.

Template Parameters

  F | the functor for the base ode system
  T1 | type of the initial state
  T2 | type of the parameters

Definition at line 25 of file coupled_ode_system.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/arr/functor/coupled_ode_system.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.